.. hiwenet documentation master file, created by
   sphinx-quickstart on Wed Sep  6 21:29:59 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Histogram weighted networks
===================================

Hiwenet helps you extracts histogram-distance weighted networks for feature extraction and advanced analysis in neuroscience and other domains.


.. image:: https://travis-ci.org/raamana/hiwenet.svg?branch=master
   :target: https://travis-ci.org/raamana/hiwenet
.. image:: https://landscape.io/github/raamana/hiwenet/master/landscape.svg?style=flat
   :target: https://landscape.io/github/raamana/hiwenet/master
   :alt: Code Health
.. image:: https://api.codacy.com/project/badge/Grade/cffd80f290544e2e824011bfccf35ff8
   :target: https://www.codacy.com/app/raamana/hiwenet?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=raamana/hiwenet&amp;utm_campaign=Badge_Grade
.. image:: https://img.shields.io/badge/python-2.7%2C%203.5%2C%203.6-blue.svg
   :alt: Python versions
.. image:: https://badge.fury.io/py/hiwenet.svg
   :target: https://badge.fury.io/py/hiwenet


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about
   installation
   API
   usage_api
   usage_cli
   guidelines
   metrics


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
